==> mediawiki-1.35.1-1-any.pkg.tar.xz: usr/share/webapps/mediawiki/languages/messages/MessagesGor.php <==
<?php
/** Gorontalo
 *
 * To improve a translation please visit https://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 */

$fallback = 'id';

$namespaceNames = [
	NS_MEDIA            => "Media",
	NS_SPECIAL          => "Spesial",
	NS_TALK             => "Lo'iya",
	NS_USER             => "Ta_ohu'uwo",
	NS_USER_TALK        => "Lo'iya_ta_ohu'owo",
	NS_PROJECT_TALK     => "Lo'iya_$1",
	NS_FILE             => "Berkas",
	NS_FILE_TALK        => "Lo'iya_berkas",
	NS_MEDIAWIKI        => "MediaWiki",
	NS_MEDIAWIKI_TALK   => "Lo'iya_MediaWiki",
	NS_TEMPLATE         => "Templat",
	NS_TEMPLATE_TALK    => "Lo'iya_templat",
	NS_HELP             => "Wubodu",
	NS_HELP_TALK        => "Lo'iya_wubodu",
	NS_CATEGORY         => "Dalala",
	NS_CATEGORY_TALK    => "Lo'iya_dalala",
];

$specialPageAliases = [
	'Activeusers'               => [ 'TaOhu\'uwoAktif' ],
	'Allmessages'               => [ 'Nga\'amilaTahuli' ],
	'AllMyUploads'              => [ 'Nga\'amilaDiletohu\'u', 'Nga\'amilaBerkasi\'u' ],
	'Allpages'                  => [ 'Nga\'amilaHalaman' ],
	'ApiHelp'                   => [ 'ApiWubodu' ],
	'ApiSandbox'                => [ 'ApiBakiLoHungayo' ],
	'Ancientpages'              => [ 'HalamanMulolo' ],
	'AutoblockList'             => [ 'AutoblockDaputari', 'DaputariAutoblocks' ],
	'Badtitle'                  => [ 'JudulMoleto' ],
	'Blankpage'                 => [ 'HalamanKosongi' ],
	'Block'                     => [ 'BlockTaOhu\'uwo' ],
	'Booksources'               => [ 'BukuBungo' ],
	'BotPasswords'              => [ 'BotTaheU\'unti' ],
	'BrokenRedirects'           => [ 'BrokenLopobale' ],
	'Categories'                => [ 'Dalala' ],
	'ChangeContentModel'        => [ 'Boli\'aTuangoModel' ],
	'ChangeCredentials'         => [ 'Boli\'aKredensial' ],
	'ChangeEmail'               => [ 'Boli\'aEmail' ],
	'ChangePassword'            => [ 'Boli\'aPassword', 'Tulo\'iPass', 'Tulo\'iPassword' ],
	'ComparePages'              => [ 'PopotadengaHlaman' ],
	'Confirmemail'              => [ 'KomfirmEmail' ],
	'Contributions'             => [ 'Kontributor', 'Kontrib' ],
	'CreateAccount'             => [ 'MohutuAkun' ],
	'Deadendpages'              => [ 'HalamanBuntu' ],
	'DeletedContributions'      => [ 'LulutaKontribusi' ],
	'DoubleRedirects'           => [ 'DubuluRedirects' ],
	'EditTags'                  => [ 'Boli\'aTags' ],
	'EditWatchlist'             => [ 'Boli\'aHeAwasiyalo' ],
	'Emailuser'                 => [ 'EmailTaOhu\'uwo', 'Email' ],
	'ExpandTemplates'           => [ 'DuhengiTemplates' ],
	'Export'                    => [ 'Ekspor' ],
	'Fewestrevisions'           => [ 'RevisiNgo\'idi' ],
	'FileDuplicateSearch'       => [ 'LoloheBerkasDubulu' ],
	'GoToInterwiki'             => [ 'NtaliOdeInterwiki' ],
	'Invalidateemail'           => [ 'TilalaTanggalEmail' ],
	'BlockList'                 => [ 'BlockDaputari', 'DaputariBlocks', 'IPBlockDputari' ],
	'LinkSearch'                => [ 'LoloheWumbuta' ],
	'LinkAccounts'              => [ 'WumbutaAkun' ],
	'Listadmins'                => [ 'DaputariAdmins' ],
	'Listbots'                  => [ 'DaputariBots' ],
	'Listfiles'                 => [ 'DaputariBerkas', 'BerkasDaputari', 'DaputariGambari' ],
	'Listgrouprights'           => [ 'DaputariGroupRights', 'TaOhu\'uwoGroupRights' ],
	'Listgrants'                => [ 'DaputariGrants' ],
	'Listredirects'             => [ 'DaputariLopobale' ],
	'ListDuplicatedFiles'       => [ 'DaputariBerkasDubulu', 'DaputariBerkasDubulu' ],
	'Listusers'                 => [ 'DaputariTaOhu\'uwo', 'TaOhu\'uwoDaputari' ],
	'Lonelypages'               => [ 'HalamanTutuwawu', 'OrphanedHalaman' ],
	'Longpages'                 => [ 'HalamanHayahaya\'o' ],
	'MediaStatistics'           => [ 'MediaStatistik' ],
	'MIMEsearch'                => [ 'MIMELolohe' ],
	'Mostcategories'            => [ 'DalalaUda\'a' ],
	'Mostimages'                => [ 'WumbutaBerkasUda\'a', 'BerkasUda\'a', 'GambariUdara' ],
	'Mostinterwikis'            => [ 'InterwikiUda\'a' ],
	'Mostlinked'                => [ 'HalamanWumbutaUda\'a', 'WumbutaUda\'a' ],
	'Mostlinkedcategories'      => [ 'WumbutaDalalaUda\'a', 'DalalaUda\'aPilomake' ],
	'Mostlinkedtemplates'       => [ 'HalamanTranscludedUda\'a', 'WumbutaUda\'aTemplate', 'TemplateUda\'aPilomake' ],
	'Mostrevisions'             => [ 'Boli\'oUda\'a' ],
	'Movepage'                  => [ 'MoheyiHalaman' ],
	'Mycontributions'           => [ 'Kontribusi\'u' ],
	'MyLanguage'                => [ 'Bahasa\'u' ],
	'Mypage'                    => [ 'Halamani\'u' ],
	'Mytalk'                    => [ 'Lo\'iya\'u' ],
	'Myuploads'                 => [ 'Diletohu\'u', 'Berkasi\'u' ],
	'Newimages'                 => [ 'BerkasBohu', 'GambariBaohu' ],
	'Newpages'                  => [ 'HalamanBohu' ],
	'PagesWithProp'             => [ 'PagesWithProp', 'Pageswithprop', 'PagesByProp', 'Pagesbyprop' ],
	'PageData'                  => [ 'DataHalaman' ],
	'PageLanguage'              => [ 'BahasaHalaman' ],
	'PasswordReset'             => [ 'ResetTaheU\'unti' ],
	'PermanentLink'             => [ 'WumbutaKakali', 'WumbKakali' ],
	'Preferences'               => [ 'Preperensi' ],
	'Prefixindex'               => [ 'PrefixIndeks' ],
	'Protectedpages'            => [ 'HalamanOdudaha' ],
	'Protectedtitles'           => [ 'JudulOdudaha' ],
	'Randompage'                => [ 'Totonula', 'HalamanTotonula' ],
	'RandomInCategory'          => [ 'TotonulaLoDalala' ],
	'Randomredirect'            => [ 'TotonulaMopobale' ],
	'Randomrootpage'            => [ 'TotonulaRootpage' ],
	'Recentchanges'             => [ 'BoheliLoboli\'aMola' ],
	'Recentchangeslinked'       => [ 'WumbutaBoheliLoboli\'aMola', 'RelatedLoboli\'a' ],
	'Redirect'                  => [ 'Mopobale' ],
	'RemoveCredentials'         => [ 'YinggilaKredensial' ],
	'Revisiondelete'            => [ 'MolulutoRevisi' ],
	'Search'                    => [ 'Lolohe' ],
	'Shortpages'                => [ 'HalamanLimbu\'o' ],
	'Specialpages'              => [ 'HalamanSpesial' ],
	'Statistics'                => [ 'Statistik', 'Stat' ],
	'TrackingCategories'        => [ 'TrackingDalala' ],
	'Uncategorizedcategories'   => [ 'DalalaJaOdalala' ],
	'Uncategorizedimages'       => [ 'BerkasJaOdalala', 'GambariJaOdalala' ],
	'Uncategorizedpages'        => [ 'HalamanJaOdalala' ],
	'Uncategorizedtemplates'    => [ 'TemplateJaOdalala' ],
	'Undelete'                  => [ 'BataliMoluluto' ],
	'UnlinkAccounts'            => [ 'BataliyaWumbutaLoAkun' ],
	'Unusedcategories'          => [ 'DalalaJaPilomake' ],
	'Unusedimages'              => [ 'BerkasJaPilomake', 'GambariJaPilomake' ],
	'Unusedtemplates'           => [ 'TemplateJaPilomake' ],
	'Unwatchedpages'            => [ 'HalamanJaOdudaha' ],
	'Upload'                    => [ 'Detohe' ],
	'UploadStash'               => [ 'DetoheStash' ],
	'Userlogin'                 => [ 'TumuwotoTaOhu\'uwo', 'Tumuwoto' ],
	'Userlogout'                => [ 'LumuwaloTaOhu\'uwo', 'Lumuwalo' ],
	'Version'                   => [ 'Versi' ],
	'Wantedcategories'          => [ 'DalalaOtohilawo' ],
	'Wantedfiles'               => [ 'BerkasOtohilawo' ],
	'Wantedpages'               => [ 'HalamanOtohilawo', 'WumbutaLorusa' ],
	'Wantedtemplates'           => [ 'TemplateOtohilawo' ],
	'Watchlist'                 => [ 'DaputariHe\'awasiyalo' ],
	'Whatlinkshere'             => [ 'WoloWumbutaTeye' ],
	'Withoutinterwiki'          => [ 'Diya\'aInterwiki' ]
];

==> mediawiki-1.36.2-1-any.pkg.tar.xz: usr/share/webapps/mediawiki/languages/messages/MessagesGor.php <==
<?php
/** Gorontalo
 *
 * To improve a translation please visit https://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 */

$fallback = 'id';

$namespaceNames = [
	NS_MEDIA            => "Media",
	NS_SPECIAL          => "Spesial",
	NS_TALK             => "Lo'iya",
	NS_USER             => "Ta_ohu'uwo",
	NS_USER_TALK        => "Lo'iya_ta_ohu'uwo",
	NS_PROJECT_TALK     => "Lo'iya_$1",
	NS_FILE             => "Berkas",
	NS_FILE_TALK        => "Lo'iya_berkas",
	NS_MEDIAWIKI        => "MediaWiki",
	NS_MEDIAWIKI_TALK   => "Lo'iya_MediaWiki",
	NS_TEMPLATE         => "Templat",
	NS_TEMPLATE_TALK    => "Lo'iya_templat",
	NS_HELP             => "Wubodu",
	NS_HELP_TALK        => "Lo'iya_wubodu",
	NS_CATEGORY         => "Dalala",
	NS_CATEGORY_TALK    => "Lo'iya_dalala",
];

$namespaceAliases = [
	"Lo'iya_ta_ohu'owo" => NS_USER_TALK, // old translation, back compat, see T269991
];

/** @phpcs-require-sorted-array */
$specialPageAliases = [
	'Activeusers'               => [ 'TaOhu\'uwoAktif' ],
	'Allmessages'               => [ 'Nga\'amilaTahuli' ],
	'AllMyUploads'              => [ 'Nga\'amilaDiletohu\'u', 'Nga\'amilaBerkasi\'u' ],
	'Allpages'                  => [ 'Nga\'amilaHalaman' ],
	'Ancientpages'              => [ 'HalamanMulolo' ],
	'ApiHelp'                   => [ 'ApiWubodu' ],
	'ApiSandbox'                => [ 'ApiBakiLoHungayo' ],
	'AutoblockList'             => [ 'AutoblockDaputari', 'DaputariAutoblocks' ],
	'Badtitle'                  => [ 'JudulMoleto' ],
	'Blankpage'                 => [ 'HalamanKosongi' ],
	'Block'                     => [ 'BlockTaOhu\'uwo' ],
	'BlockList'                 => [ 'BlockDaputari', 'DaputariBlocks', 'IPBlockDputari' ],
	'Booksources'               => [ 'BukuBungo' ],
	'BotPasswords'              => [ 'BotTaheU\'unti' ],
	'BrokenRedirects'           => [ 'BrokenLopobale' ],
	'Categories'                => [ 'Dalala' ],
	'ChangeContentModel'        => [ 'Boli\'aTuangoModel' ],
	'ChangeCredentials'         => [ 'Boli\'aKredensial' ],
	'ChangeEmail'               => [ 'Boli\'aEmail' ],
	'ChangePassword'            => [ 'Boli\'aPassword', 'Tulo\'iPass', 'Tulo\'iPassword' ],
	'ComparePages'              => [ 'PopotadengaHlaman' ],
	'Confirmemail'              => [ 'KomfirmEmail' ],
	'Contributions'             => [ 'Kontributor', 'Kontrib' ],
	'CreateAccount'             => [ 'MohutuAkun' ],
	'Deadendpages'              => [ 'HalamanBuntu' ],
	'DeletedContributions'      => [ 'LulutaKontribusi' ],
	'DoubleRedirects'           => [ 'DubuluRedirects' ],
	'EditTags'                  => [ 'Boli\'aTags' ],
	'EditWatchlist'             => [ 'Boli\'aHeAwasiyalo' ],
	'Emailuser'                 => [ 'EmailTaOhu\'uwo', 'Email' ],
	'ExpandTemplates'           => [ 'DuhengiTemplates' ],
	'Export'                    => [ 'Ekspor' ],
	'Fewestrevisions'           => [ 'RevisiNgo\'idi' ],
	'FileDuplicateSearch'       => [ 'LoloheBerkasDubulu' ],
	'GoToInterwiki'             => [ 'NtaliOdeInterwiki' ],
	'Invalidateemail'           => [ 'TilalaTanggalEmail' ],
	'LinkAccounts'              => [ 'WumbutaAkun' ],
	'LinkSearch'                => [ 'LoloheWumbuta' ],
	'Listadmins'                => [ 'DaputariAdmins' ],
	'Listbots'                  => [ 'DaputariBots' ],
	'ListDuplicatedFiles'       => [ 'DaputariBerkasDubulu', 'DaputariBerkasDubulu' ],
	'Listfiles'                 => [ 'DaputariBerkas', 'BerkasDaputari', 'DaputariGambari' ],
	'Listgrants'                => [ 'DaputariGrants' ],
	'Listgrouprights'           => [ 'DaputariGroupRights', 'TaOhu\'uwoGroupRights' ],
	'Listredirects'             => [ 'DaputariLopobale' ],
	'Listusers'                 => [ 'DaputariTaOhu\'uwo', 'TaOhu\'uwoDaputari' ],
	'Lonelypages'               => [ 'HalamanTutuwawu', 'OrphanedHalaman' ],
	'Longpages'                 => [ 'HalamanHayahaya\'o' ],
	'MediaStatistics'           => [ 'MediaStatistik' ],
	'MIMEsearch'                => [ 'MIMELolohe' ],
	'Mostcategories'            => [ 'DalalaUda\'a' ],
	'Mostimages'                => [ 'WumbutaBerkasUda\'a', 'BerkasUda\'a', 'GambariUdara' ],
	'Mostinterwikis'            => [ 'InterwikiUda\'a' ],
	'Mostlinked'                => [ 'HalamanWumbutaUda\'a', 'WumbutaUda\'a' ],
	'Mostlinkedcategories'      => [ 'WumbutaDalalaUda\'a', 'DalalaUda\'aPilomake' ],
	'Mostlinkedtemplates'       => [ 'HalamanTranscludedUda\'a', 'WumbutaUda\'aTemplate', 'TemplateUda\'aPilomake' ],
	'Mostrevisions'             => [ 'Boli\'oUda\'a' ],
	'Movepage'                  => [ 'MoheyiHalaman' ],
	'Mycontributions'           => [ 'Kontribusi\'u' ],
	'MyLanguage'                => [ 'Bahasa\'u' ],
	'Mypage'                    => [ 'Halamani\'u' ],
	'Mytalk'                    => [ 'Lo\'iya\'u' ],
	'Myuploads'                 => [ 'Diletohu\'u', 'Berkasi\'u' ],
	'Newimages'                 => [ 'BerkasBohu', 'GambariBaohu' ],
	'Newpages'                  => [ 'HalamanBohu' ],
	'PageData'                  => [ 'DataHalaman' ],
	'PageLanguage'              => [ 'BahasaHalaman' ],
	'PagesWithProp'             => [ 'PagesWithProp', 'Pageswithprop', 'PagesByProp', 'Pagesbyprop' ],
	'PasswordReset'             => [ 'ResetTaheU\'unti' ],
	'PermanentLink'             => [ 'WumbutaKakali', 'WumbKakali' ],
	'Preferences'               => [ 'Preperensi' ],
	'Prefixindex'               => [ 'PrefixIndeks' ],
	'Protectedpages'            => [ 'HalamanOdudaha' ],
	'Protectedtitles'           => [ 'JudulOdudaha' ],
	'RandomInCategory'          => [ 'TotonulaLoDalala' ],
	'Randompage'                => [ 'Totonula', 'HalamanTotonula' ],
	'Randomredirect'            => [ 'TotonulaMopobale' ],
	'Randomrootpage'            => [ 'TotonulaRootpage' ],
	'Recentchanges'             => [ 'BoheliLoboli\'aMola' ],
	'Recentchangeslinked'       => [ 'WumbutaBoheliLoboli\'aMola', 'RelatedLoboli\'a' ],
	'Redirect'                  => [ 'Mopobale' ],
	'RemoveCredentials'         => [ 'YinggilaKredensial' ],
	'Revisiondelete'            => [ 'MolulutoRevisi' ],
	'Search'                    => [ 'Lolohe' ],
	'Shortpages'                => [ 'HalamanLimbu\'o' ],
	'Specialpages'              => [ 'HalamanSpesial' ],
	'Statistics'                => [ 'Statistik', 'Stat' ],
	'TrackingCategories'        => [ 'TrackingDalala' ],
	'Uncategorizedcategories'   => [ 'DalalaJaOdalala' ],
	'Uncategorizedimages'       => [ 'BerkasJaOdalala', 'GambariJaOdalala' ],
	'Uncategorizedpages'        => [ 'HalamanJaOdalala' ],
	'Uncategorizedtemplates'    => [ 'TemplateJaOdalala' ],
	'Undelete'                  => [ 'BataliMoluluto' ],
	'UnlinkAccounts'            => [ 'BataliyaWumbutaLoAkun' ],
	'Unusedcategories'          => [ 'DalalaJaPilomake' ],
	'Unusedimages'              => [ 'BerkasJaPilomake', 'GambariJaPilomake' ],
	'Unusedtemplates'           => [ 'TemplateJaPilomake' ],
	'Unwatchedpages'            => [ 'HalamanJaOdudaha' ],
	'Upload'                    => [ 'Detohe' ],
	'UploadStash'               => [ 'DetoheStash' ],
	'Userlogin'                 => [ 'TumuwotoTaOhu\'uwo', 'Tumuwoto' ],
	'Userlogout'                => [ 'LumuwaloTaOhu\'uwo', 'Lumuwalo' ],
	'Version'                   => [ 'Versi' ],
	'Wantedcategories'          => [ 'DalalaOtohilawo' ],
	'Wantedfiles'               => [ 'BerkasOtohilawo' ],
	'Wantedpages'               => [ 'HalamanOtohilawo', 'WumbutaLorusa' ],
	'Wantedtemplates'           => [ 'TemplateOtohilawo' ],
	'Watchlist'                 => [ 'DaputariHe\'awasiyalo' ],
	'Whatlinkshere'             => [ 'WoloWumbutaTeye' ],
	'Withoutinterwiki'          => [ 'Diya\'aInterwiki' ]
];
